const PACKAGE_NAME = '@talend/react-components';

function matches(path) {
	return path.node.source.value.startsWith(PACKAGE_NAME);
}

module.exports = function transform({ types }) {
	return {
		visitor: {
			Program(path) {
				const importSpecifiers = [];
				let lastImport;

				path.traverse({
					ImportDeclaration: {
						exit(importDeclarationPath) {
							if (matches(importDeclarationPath)) {
								importSpecifiers.push(
									...importDeclarationPath.node.specifiers.map(({ local, imported, type }) => {
										const localName = local.name;
										if (type === 'ImportNamespaceSpecifier') {
											return types.importNamespaceSpecifier(types.identifier(localName));
										}

										const importedName = imported ? imported.name : localName;
										return types.importSpecifier(
											types.identifier(localName),
											types.identifier(importedName),
										);
									}),
								);
								importDeclarationPath.remove();
							}
							lastImport = importDeclarationPath;
						},
					},
				});

				if (importSpecifiers.length && lastImport) {
					const source = types.stringLiteral(PACKAGE_NAME);
					const imp = types.importDeclaration(importSpecifiers, source);
					lastImport.insertAfter(imp);
				}
			},
		},
	};
};
